@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -73,7 +73,7 @@ __all__ = ("AccessAnalyzerClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -91,7 +91,7 @@ class Exceptions:
 
 class AccessAnalyzerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html)
     """
 
@@ -110,7 +110,7 @@ class AccessAnalyzerClient(BaseClient):
         Retroactively applies the archive rule to existing findings that meet the
         archive rule criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#apply_archive_rule)
         """
 
@@ -118,7 +118,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#can_paginate)
         """
 
@@ -126,7 +126,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Cancels the requested policy generation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#cancel_policy_generation)
         """
 
@@ -134,14 +134,14 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerArn: str,
-        configurations: Dict[str, "ConfigurationTypeDef"],
+        configurations: Mapping[str, "ConfigurationTypeDef"],
         clientToken: str = None
     ) -> CreateAccessPreviewResponseTypeDef:
         """
         Creates an access preview that allows you to preview IAM Access Analyzer
         findings for your resource before deploying resource permissions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_access_preview)
         """
 
@@ -150,14 +150,14 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerName: str,
         type: TypeType,
-        archiveRules: List["InlineArchiveRuleTypeDef"] = None,
+        archiveRules: Sequence["InlineArchiveRuleTypeDef"] = None,
         clientToken: str = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> CreateAnalyzerResponseTypeDef:
         """
         Creates an analyzer for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_analyzer)
         """
 
@@ -165,14 +165,14 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerName: str,
-        filter: Dict[str, "CriterionTypeDef"],
+        filter: Mapping[str, "CriterionTypeDef"],
         ruleName: str,
         clientToken: str = None
     ) -> None:
         """
         Creates an archive rule for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_archive_rule)
         """
 
@@ -180,7 +180,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Deletes the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_analyzer)
         """
 
@@ -190,21 +190,21 @@ class AccessAnalyzerClient(BaseClient):
         """
         Deletes the specified archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_archive_rule)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#generate_presigned_url)
         """
 
@@ -214,7 +214,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about an access preview for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_access_preview)
         """
 
@@ -224,7 +224,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about a resource that was analyzed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzed_resource)
         """
 
@@ -232,7 +232,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzer)
         """
 
@@ -242,7 +242,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about an archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_archive_rule)
         """
 
@@ -250,7 +250,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about the specified finding.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_finding)
         """
 
@@ -264,7 +264,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves the policy that was generated using `StartPolicyGeneration` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_generated_policy)
         """
 
@@ -273,7 +273,7 @@ class AccessAnalyzerClient(BaseClient):
         *,
         accessPreviewId: str,
         analyzerArn: str,
-        filter: Dict[str, "CriterionTypeDef"] = None,
+        filter: Mapping[str, "CriterionTypeDef"] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> ListAccessPreviewFindingsResponseTypeDef:
@@ -281,7 +281,7 @@ class AccessAnalyzerClient(BaseClient):
         Retrieves a list of access preview findings generated by the specified access
         preview.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_preview_findings)
         """
 
@@ -291,7 +291,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of access previews for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_previews)
         """
 
@@ -307,7 +307,7 @@ class AccessAnalyzerClient(BaseClient):
         Retrieves a list of resources of the specified type that have been analyzed by
         the specified analyzer..
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzed_resources)
         """
 
@@ -317,7 +317,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of analyzers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzers)
         """
 
@@ -327,7 +327,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of archive rules created for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_archive_rules)
         """
 
@@ -335,7 +335,7 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerArn: str,
-        filter: Dict[str, "CriterionTypeDef"] = None,
+        filter: Mapping[str, "CriterionTypeDef"] = None,
         maxResults: int = None,
         nextToken: str = None,
         sort: "SortCriteriaTypeDef" = None
@@ -343,7 +343,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of findings generated by the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_findings)
         """
 
@@ -353,7 +353,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Lists all of the policy generations requested in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_policy_generations)
         """
 
@@ -361,7 +361,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of tags applied to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_tags_for_resource)
         """
 
@@ -375,7 +375,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Starts the policy generation request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_policy_generation)
         """
 
@@ -383,23 +383,23 @@ class AccessAnalyzerClient(BaseClient):
         """
         Immediately starts a scan of the policies applied to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_resource_scan)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Adds a tag to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes a tag from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#untag_resource)
         """
 
@@ -407,14 +407,14 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerName: str,
-        filter: Dict[str, "CriterionTypeDef"],
+        filter: Mapping[str, "CriterionTypeDef"],
         ruleName: str,
         clientToken: str = None
     ) -> None:
         """
         Updates the criteria and values for the specified archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_archive_rule)
         """
 
@@ -424,13 +424,13 @@ class AccessAnalyzerClient(BaseClient):
         analyzerArn: str,
         status: FindingStatusUpdateType,
         clientToken: str = None,
-        ids: List[str] = None,
+        ids: Sequence[str] = None,
         resourceArn: str = None
     ) -> None:
         """
         Updates the status for the specified findings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_findings)
         """
 
@@ -446,7 +446,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Requests the validation of a policy and returns a list of findings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#validate_policy)
         """
 
@@ -455,7 +455,7 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_access_preview_findings"]
     ) -> ListAccessPreviewFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
         """
 
@@ -464,7 +464,7 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_access_previews"]
     ) -> ListAccessPreviewsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
         """
 
@@ -473,14 +473,14 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_analyzed_resources"]
     ) -> ListAnalyzedResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_analyzers"]) -> ListAnalyzersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
         """
 
@@ -489,14 +489,14 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_archive_rules"]
     ) -> ListArchiveRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
         """
 
@@ -505,13 +505,13 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_policy_generations"]
     ) -> ListPolicyGenerationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["validate_policy"]) -> ValidatePolicyPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
         """
