@@ -32,7 +32,7 @@ Usage::
     validate_policy_paginator: ValidatePolicyPaginator = client.get_paginator("validate_policy")
     ```
 """
-from typing import Dict, Generic, Iterator, TypeVar
+from typing import Generic, Iterator, Mapping, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -76,7 +76,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListAccessPreviewFindingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
     """
 
@@ -85,18 +85,18 @@ class ListAccessPreviewFindingsPaginator(Boto3Paginator):
         *,
         accessPreviewId: str,
         analyzerArn: str,
-        filter: Dict[str, "CriterionTypeDef"] = None,
+        filter: Mapping[str, "CriterionTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListAccessPreviewFindingsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
         """
 
 
 class ListAccessPreviewsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
     """
 
@@ -104,14 +104,14 @@ class ListAccessPreviewsPaginator(Boto3Paginator):
         self, *, analyzerArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListAccessPreviewsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
         """
 
 
 class ListAnalyzedResourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
     """
 
@@ -123,14 +123,14 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListAnalyzedResourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
         """
 
 
 class ListAnalyzersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
     """
 
@@ -138,14 +138,14 @@ class ListAnalyzersPaginator(Boto3Paginator):
         self, *, type: TypeType = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListAnalyzersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
         """
 
 
 class ListArchiveRulesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
     """
 
@@ -153,14 +153,14 @@ class ListArchiveRulesPaginator(Boto3Paginator):
         self, *, analyzerName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListArchiveRulesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
         """
 
 
 class ListFindingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
     """
 
@@ -168,19 +168,19 @@ class ListFindingsPaginator(Boto3Paginator):
         self,
         *,
         analyzerArn: str,
-        filter: Dict[str, "CriterionTypeDef"] = None,
+        filter: Mapping[str, "CriterionTypeDef"] = None,
         sort: "SortCriteriaTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListFindingsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
         """
 
 
 class ListPolicyGenerationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
     """
 
@@ -188,14 +188,14 @@ class ListPolicyGenerationsPaginator(Boto3Paginator):
         self, *, principalArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListPolicyGenerationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
         """
 
 
 class ValidatePolicyPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
     """
 
@@ -208,6 +208,6 @@ class ValidatePolicyPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ValidatePolicyResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
         """
